package com.sitemesh.mapper;

import java.util.Map;
import com.sitemesh.Decorator;

/**
 * Default implementation of Decorator. All properties are set by the
 * constructor.
 *
 * @author <a href="mailto:joe@truemesh.com">Joe Walnes</a>
 * @version $Revision: 1.5 $
 *
 * @see com.sitemesh.Decorator
 * @see com.sitemesh.mapper.DefaultDecoratorMapper
 */
public class DefaultDecorator implements Decorator {

	/**
	 * @see #getPage()
	 */
	protected String page;

	/**
	 * @see #getName()
	 */
	protected String name;

	/**
	 * @see #getInitParam(java.lang.String)
	 */
	protected Map parameters;

	/**
	 * Constructor to set all properties.
	 */
	public DefaultDecorator( String name, String page, Map parameters ) {
		this.name = name;
		this.page = page;
		this.parameters = parameters;
	}

	/**
	 * URI of Servlet/JSP to dispatch request to (relative to
	 * web-app context).
	 */
	public String getPage() {
		return page;
	}

	/**
	 * Name of Decorator. For information purposes only.
	 */
	public String getName() {
		return name;
	}

	/**
	 * Return init parameter of Decorator.
	 *
	 * @param paramName Key of parameter.
	 * @return Value of parameter or null if not found.
	 */
	public String getInitParam( String paramName ) {
		if ( parameters == null ) return null;
		if ( !parameters.containsKey( name ) ) return null;
		return ( String )parameters.get( name );
	}

}
